summaryrefslogtreecommitdiffstats
path: root/kutils/kreplacedialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kutils/kreplacedialog.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kutils/kreplacedialog.cpp')
-rw-r--r--kutils/kreplacedialog.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kutils/kreplacedialog.cpp b/kutils/kreplacedialog.cpp
index 88c006b4d..deef5b529 100644
--- a/kutils/kreplacedialog.cpp
+++ b/kutils/kreplacedialog.cpp
@@ -32,22 +32,22 @@
/**
* we need to insert the strings after the dialog is set
* up, otherwise TQComboBox will deliver an aweful big sizeHint
* for long replacement texts.
*/
class KReplaceDialog::KReplaceDialogPrivate {
public:
KReplaceDialogPrivate() : m_initialShowDone(false) {}
- TQStringList replaceStrings;
+ TQStringList tqreplaceStrings;
bool m_initialShowDone;
};
-KReplaceDialog::KReplaceDialog(TQWidget *parent, const char *name, long options, const TQStringList &findStrings, const TQStringList &replaceStrings, bool hasSelection) :
+KReplaceDialog::KReplaceDialog(TQWidget *parent, const char *name, long options, const TQStringList &tqfindStrings, const TQStringList &tqreplaceStrings, bool hasSelection) :
KFindDialog(parent, name, true)
{
d = new KReplaceDialogPrivate;
- d->replaceStrings = replaceStrings;
- init(true, findStrings, hasSelection);
+ d->tqreplaceStrings = tqreplaceStrings;
+ init(true, tqfindStrings, hasSelection);
setOptions(options);
}
@@ -62,10 +62,10 @@ void KReplaceDialog::showEvent( TQShowEvent *e )
{
d->m_initialShowDone = true; // only once
- if (!d->replaceStrings.isEmpty())
+ if (!d->tqreplaceStrings.isEmpty())
{
- setReplacementHistory(d->replaceStrings);
- m_replace->lineEdit()->setText( d->replaceStrings[0] );
+ setReplacementHistory(d->tqreplaceStrings);
+ m_tqreplace->lineEdit()->setText( d->tqreplaceStrings[0] );
}
}
@@ -84,27 +84,27 @@ long KReplaceDialog::options() const
return options;
}
-TQWidget *KReplaceDialog::replaceExtension()
+TQWidget *KReplaceDialog::tqreplaceExtension()
{
- if (!m_replaceExtension)
+ if (!m_tqreplaceExtension)
{
- m_replaceExtension = new TQWidget(m_replaceGrp);
- m_replaceLayout->addMultiCellWidget(m_replaceExtension, 3, 3, 0, 1);
+ m_tqreplaceExtension = new TQWidget(m_tqreplaceGrp);
+ m_tqreplaceLayout->addMultiCellWidget(m_tqreplaceExtension, 3, 3, 0, 1);
}
- return m_replaceExtension;
+ return m_tqreplaceExtension;
}
-TQString KReplaceDialog::replacement() const
+TQString KReplaceDialog::tqreplacement() const
{
- return m_replace->currentText();
+ return m_tqreplace->currentText();
}
-TQStringList KReplaceDialog::replacementHistory() const
+TQStringList KReplaceDialog::tqreplacementHistory() const
{
- TQStringList lst = m_replace->historyItems();
+ TQStringList lst = m_tqreplace->historyItems();
// historyItems() doesn't tell us about the case of replacing with an empty string
- if ( m_replace->lineEdit()->text().isEmpty() )
+ if ( m_tqreplace->lineEdit()->text().isEmpty() )
lst.prepend( TQString::null );
return lst;
}
@@ -119,9 +119,9 @@ void KReplaceDialog::setOptions(long options)
void KReplaceDialog::setReplacementHistory(const TQStringList &strings)
{
if (strings.count() > 0)
- m_replace->setHistoryItems(strings, true);
+ m_tqreplace->setHistoryItems(strings, true);
else
- m_replace->clearHistory();
+ m_tqreplace->clearHistory();
}
void KReplaceDialog::slotOk()
@@ -133,13 +133,13 @@ void KReplaceDialog::slotOk()
int caps = r.numCaptures();
TQRegExp check(TQString("((?:\\\\)+)(\\d+)"));
int p = 0;
- TQString rep = replacement();
+ TQString rep = tqreplacement();
while ( (p = check.search( rep, p ) ) > -1 )
{
if ( check.cap(1).length()%2 && check.cap(2).toInt() > caps )
{
KMessageBox::information( this, i18n(
- "Your replacement string is referencing a capture greater than '\\%1', ").arg( caps ) +
+ "Your tqreplacement string is referencing a capture greater than '\\%1', ").arg( caps ) +
( caps ?
i18n("but your pattern only defines 1 capture.",
"but your pattern only defines %n captures.", caps ) :
@@ -153,8 +153,8 @@ void KReplaceDialog::slotOk()
}
KFindDialog::slotOk();
- m_replace->addToHistory(replacement());
+ m_tqreplace->addToHistory(tqreplacement());
}
-// kate: space-indent on; indent-width 4; replace-tabs on;
+// kate: space-indent on; indent-width 4; tqreplace-tabs on;
#include "kreplacedialog.moc"
@@ -32,22 +32,22 @@
/**
* we need to insert the strings after the dialog is set
- * up, otherwise TQComboBox will deliver an aweful big sizeHint
- * for long replacement texts.
+ * up, otherwise TQComboBox will deliver an aweful big tqsizeHint
+ * for long tqreplacement texts.
*/
class KReplaceDialog::KReplaceDialogPrivate {